@@ -4,10 +4,10 @@ use File::Spec;
 use lib File::Spec->catdir(dirname(__FILE__), 'lib');
 use MyProj::DB;
 use MyProj::DB::Schema;
-# use DBIx::QueryLog;
+#use DBIx::QueryLog;
 
-my $db = MyProj::DB->new(connect_info => ["dbi:mysql:database=test", "root", "", { mysql_multi_statements => 1 } ]);
-$db->execute(MyProj::DB::Schema->output);
+my $db = MyProj::DB->new(connect_info => ["dbi:SQLite:dbname=:memory:", "", ""]);
+$db->execute($_) for split /;/, MyProj::DB::Schema->output;
 
 my $author_id = $db->insert_and_fetch_id(author => { name => 'songmu' });
 
@@ -29,7 +29,7 @@ say '$module->name:         ', $module->name;         ## Riji
 say '$module->author->name: ', $module->author->name; ## SONGMU
 
 my $author = $db->select(author => {
-    name => 'SONGMU',
+    name => 'songmu',
 }, {
     limit => 1,
     relay => [qw/modules/],
