@@ -1,5 +1,5 @@
 package t::DB;
-use Mouse;
+use Mouse v2.4.5;
 extends qw/Aniki/;
 
 __PACKAGE__->setup(
